beamprofiler.niso.characterizing\_parameters.plateau\_uniformity
================================================================

.. currentmodule:: beamprofiler.niso.characterizing_parameters

.. autofunction:: plateau_uniformity